Adds persistent lease support to a document migration backend.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
acquireLease(
String lockEntity, {required Duration ttl}) → Future< MigrationLease> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
releaseLease(
String lockEntity, MigrationLease lease) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
verifyLease(
String lockEntity, MigrationLease lease) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited