MigrationForeignKeyDefinition class final

Describes a foreign key expected on an entity.

Constructors

MigrationForeignKeyDefinition({required String entityName, required String name, required List<String> fields, required String referencedEntity, required List<String> referencedFields, MigrationReferentialAction onDelete = MigrationReferentialAction.noAction, MigrationReferentialAction onUpdate = MigrationReferentialAction.noAction})
const

Properties

entityName → String
final
fields → List<String>
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
onDelete → MigrationReferentialAction
final
onUpdate → MigrationReferentialAction
final
referencedEntity → String
final
referencedFields → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited